@@ -785,7 +785,7 @@ class LogoutHandler(tornado.web.RequestHandler):
         self.clear_cookie("id_token")
         self.clear_cookie("access_token")
         self.clear_cookie(STATE_COOKIE_NAME)
-        self.redirect("/")
+        self.redirect(self.request.uri.replace('/logout', ''))
 
 
 class OAuthProvider(AuthProvider):
@@ -820,7 +820,7 @@ class OAuthProvider(AuthProvider):
 
     @property
     def logout_url(self):
-        return "/logout"
+        return '/logout'
 
     @property
     def logout_handler(self):
@@ -834,8 +834,13 @@ class BasicLoginHandler(RequestHandler):
             errormessage = self.get_argument("error")
         except Exception:
             errormessage = ""
+
+        next_url = self.get_argument('next', None)
+        if next_url:
+            self.set_cookie("next_url", next_url)
         html = self._basic_login_template.render(
-            errormessage=errormessage, PANEL_CDN=CDN_DIST
+            errormessage=errormessage,
+            PANEL_CDN=CDN_DIST
         )
         self.write(html)
 
@@ -861,10 +866,11 @@ class BasicLoginHandler(RequestHandler):
         auth = self._validate(username, password)
         if auth:
             self.set_current_user(username)
-            self.redirect("/")
+            next_url = self.get_cookie("next_url", "/")
+            self.redirect(next_url)
         else:
-            error_msg = "?error=" + tornado.escape.url_escape("Login incorrect")
-            self.redirect('/login' + error_msg)
+            error_msg = "?error=" + tornado.escape.url_escape("Invalid username or password!")
+            self.redirect(self.request.uri + error_msg)
 
     def set_current_user(self, user):
         if not user:
