@@ -11,8 +11,8 @@ export class IPyWidgetView extends HTMLBoxView {
   private ipychildren: any[]
   private manager: any
 
-  override async lazy_initialize(): Promise<void> {
-    await super.lazy_initialize()
+  initialize(): void {
+    super.initialize()
     let manager: any
     if ((Jupyter != null) && (Jupyter.notebook != null))
       manager = Jupyter.notebook.kernel.widget_manager
@@ -24,17 +24,11 @@ export class IPyWidgetView extends HTMLBoxView {
     }
     this.manager = manager
     this.ipychildren = []
-    const {spec, state} = this.model.bundle
-    const models = await manager.set_state(state)
-    const model = models.find((item: any) => item.model_id == spec.model_id)
-    if (model != null) {
-      const view = await this.manager.create_view(model, {el: this.el})
-      this.ipyview = view
-      if (view.children_views) {
-        for (const child of view.children_views.views)
-          this.ipychildren.push(await child)
-      }
-    }
+  }
+
+  override remove(): void {
+    this.ipyview.remove()
+    super.remove()
   }
 
   protected _ipy_stylesheets(): StyleSheetLike[] {
@@ -59,13 +53,25 @@ export class IPyWidgetView extends HTMLBoxView {
 
   render(): void {
     super.render()
-    if (this.ipyview != null) {
+    const {spec, state} = this.model.bundle
+    this.manager.set_state(state).then(async (models: any) => {
+      const model = models.find((item: any) => item.model_id == spec.model_id)
+      if (model == null)
+	return
+
+      const view = await this.manager.create_view(model, {el: this.el})
+      this.ipyview = view
+      this.ipychildren = []
+      if (view.children_views) {
+        for (const child of view.children_views.views)
+          this.ipychildren.push(await child)
+      }
       this.shadow_el.appendChild(this.ipyview.el)
       this.ipyview.trigger('displayed', this.ipyview)
       for (const child of this.ipychildren)
         child.trigger('displayed', child)
       this.invalidate_layout()
-    }
+    })
   }
 }
 
