@@ -296,7 +296,9 @@ export class DataTabulatorView extends HTMLBoxView {
 
     const p = this.model.properties
     const {configuration, layout, columns, groupby} = p;
-    this.on_change([configuration, layout, groupby], debounce(() => this.invalidate_render(), 20, false))
+    this.on_change([configuration, layout, groupby], debounce(() => {
+      this.invalidate_render()
+    }, 20, false))
 
     this.on_change([columns], () => {
       this.tabulator.setColumns(this.getColumns())
@@ -416,6 +418,8 @@ export class DataTabulatorView extends HTMLBoxView {
   }
 
   render(): void {
+    if (this.tabulator != null)
+      this.tabulator.destroy()
     super.render()
     this._initializing = true
     const container = div({style: "display: contents;"})
@@ -599,10 +603,11 @@ export class DataTabulatorView extends HTMLBoxView {
   }
 
   get child_models(): LayoutDOM[] {
-    const children = []
+    const children: LayoutDOM[] = []
     for (const idx of this.model.expanded) {
-      if (this.model.children.has(idx))
-        children.push(this.model.children.get(idx))
+      const child = this.model.children.get?.(idx)
+      if (child != null)
+	children.push(child)
     }
     return children
   }
@@ -617,17 +622,18 @@ export class DataTabulatorView extends HTMLBoxView {
         this._render_row(row, false)
       }
       this._update_children()
-      this.tabulator.rowManager.adjustTableSize()
+      if (this.tabulator.rowManager.renderer != null)
+	this.tabulator.rowManager.adjustTableSize()
       this.invalidate_layout()
     })
   }
 
   _render_row(row: any, resize: boolean = true): void {
     const index = row._row?.data._index
-    if (!this.model.expanded.includes(index) || !this.model.children.has(index))
+    if (!this.model.expanded.includes(index) || this.model.children.get(index) == null)
       return
     const model = this.model.children.get(index)
-    const view = this._child_views.get(model)
+    const view = model == null ? null : this._child_views.get(model)
     if (view == null)
       return
     const rowEl = row.getElement()
@@ -637,8 +643,10 @@ export class DataTabulatorView extends HTMLBoxView {
     const viewEl = div({style: "background-color: " + bg +"; margin-left:" + neg_margin + "; max-width: 100%; overflow-x: hidden;"})
     viewEl.appendChild(view.el)
     rowEl.appendChild(viewEl)
-    view.render()
-    view.after_render()
+    if (!view.has_finished()) {
+      view.render()
+      view.after_render()
+    }
     if (resize) {
       this._update_children()
       this.tabulator.rowManager.adjustTableSize()
@@ -660,8 +668,8 @@ export class DataTabulatorView extends HTMLBoxView {
       expanded.push(index)
     else {
       const removed = expanded.splice(exp_index, 1)[0]
-      if (removed in this.model.children) {
-        const model = this.model.children[removed]
+      const model = this.model.children.get?.(removed)
+      if (model != null) {
         const view = this._child_views.get(model)
         if (view !== undefined && view.el != null)
           undisplay(view.el)
@@ -672,7 +680,7 @@ export class DataTabulatorView extends HTMLBoxView {
       return
     let ready = true
     for (const idx of this.model.expanded) {
-      if (!(idx in this.model.children)) {
+      if (this.model.children.get?.(idx) == null) {
         ready = false
         break
       }
@@ -871,6 +879,8 @@ export class DataTabulatorView extends HTMLBoxView {
   // Update table
 
   setData(): void {
+    if (this._initializing || this._building || !this.tabulator.initialized)
+      return
     const data = this.getData()
     if (this.model.pagination != null)
       this.tabulator.rowManager.setData(data, true, false)
@@ -934,7 +944,7 @@ export class DataTabulatorView extends HTMLBoxView {
 
   setStyles(): void {
     const style_data = this.model.cell_styles.data
-    if (this.tabulator == null || this.tabulator.getDataCount() == 0 || !style_data.size)
+    if (this.tabulator == null || this.tabulator.getDataCount() == 0 || style_data == null || !style_data.size)
       return
     this._applied_styles = false
     for (const r of style_data.keys()) {
@@ -997,7 +1007,7 @@ export class DataTabulatorView extends HTMLBoxView {
   }
 
   setSelection(): void {
-    if (this.tabulator == null || this._selection_updating)
+    if (this.tabulator == null || this._initializing || this._selection_updating || !this.tabulator.initialized)
       return
 
     const indices = this.model.source.selected.indices;
@@ -1115,7 +1125,7 @@ export namespace DataTabulator {
   export type Props = HTMLBox.Props & {
     aggregators: p.Property<any>
     buttons: p.Property<any>
-    children: p.Property<any>
+    children: p.Property<Map<number, LayoutDOM>>
     columns: p.Property<TableColumn[]>
     configuration: p.Property<any>
     download: p.Property<boolean>
@@ -1160,7 +1170,7 @@ export class DataTabulator extends HTMLBox {
     this.define<DataTabulator.Props>(({Any, Array, Boolean, Nullable, Number, Ref, String}) => ({
       aggregators:    [ Any,                     {} ],
       buttons:        [ Any,                     {} ],
-      children:       [ Any,                     {} ],
+      children:       [ Any,              new Map() ],
       configuration:  [ Any,                     {} ],
       columns:        [ Array(Ref(TableColumn)), [] ],
       download:       [ Boolean,              false ],
