@@ -40,6 +40,8 @@ def test_viewable_ipywidget():
 def test_viewable_signature(viewable):
     from inspect import Parameter, signature
     parameters = signature(viewable).parameters
+    if getattr(getattr(viewable, '_param__private', object), 'signature', None):
+        pytest.skip('Signature already set by Param')
     assert 'params' in parameters
     try:
         assert parameters['params'] == Parameter('params', Parameter.VAR_KEYWORD, annotation='Any')
