@@ -457,3 +457,17 @@ def relative_to(path, other_path):
         return True
     except Exception:
         return False
+
+_unset = object()
+
+def param_watchers(parameterized, value=_unset):
+    if Version(param.__version__) <= Version('2.0.0a2'):
+        if value is not _unset:
+            parameterized._param_watchers = value
+        else:
+            return parameterized._param_watchers
+    else:
+        if value is not _unset:
+            parameterized.param.watchers = value
+        else:
+            return parameterized.param.watchers
